PickerState

Struct PickerState 

pub struct PickerState {
    pub input_state: TextState<'static>,
    pub prompt_text: Cow<'static, str>,
    /* private fields */
}
State of the picker component

Fields

input_state: TextState<'static>

Current input pattern

prompt_text: Cow<'static, str>

Prompt text to display

Implementations

Source

impl PickerState

pub fn new( prompt: impl Into<Cow<'static, str>>, items: Vec<PickerItem>, allow_custom_input: bool, ) -> Self

Create a new picker with items

pub fn pattern(&self) -> &str

Get current input pattern

pub fn update_filter(&mut self)

Update the filter based on current input pattern

pub fn selected(&self) -> Option<&PickerItem>

Get the currently selected item, if any

pub fn filtered_items(&self) -> impl Iterator<Item = (usize, &PickerItem)>

Get all filtered items with their original indices Custom input item (if present) is always last with index usize::MAX

pub fn next(&mut self)

Move cursor to next item

pub fn previous(&mut self)

Move cursor to previous item

pub fn cursor(&self) -> usize

Get current cursor position

pub fn total_items(&self) -> usize

Get total number of items

pub fn filtered_count(&self) -> usize

Get number of filtered items

pub fn match_indices(&self, item_index: usize) -> Option<Vec<usize>>

Get the fuzzy match positions for a given item (for highlighting)

pub fn status(&self) -> &PickerStatus

Get current status

pub fn done(&mut self)

Mark picker as done (user selected an item)

pub fn cancel(&mut self)

Mark picker as cancelled (user cancelled)

pub fn is_done(&self) -> bool

Check if picker is done

pub fn is_cancelled(&self) -> bool

Check if picker is cancelled